library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity CFG_SELECTOR is
    Port ( CLK     : in std_logic;
           RST     : in std_logic;
			  DONE    : in std_logic;
			  CFG_SEL : in std_logic;
           CFG_ENB : out std_logic );
end CFG_SELECTOR;

architecture RTL of CFG_SELECTOR is

signal STATE : std_logic_vector( 1 downto 0 );
constant S0  : std_logic_vector := "00";
constant S1  : std_logic_vector := "01";
constant S2  : std_logic_vector := "10";
constant S3  : std_logic_vector := "11";

begin

process( CLK, RST ) begin
	if( RST ='1') then
		CFG_ENB <= '0';
		STATE   <= S0;
	elsif( CLK'event and CLK='1') then
		case STATE is
			when S0 =>
				if( CFG_SEL = '1') then
					CFG_ENB <= '1';
					STATE   <= S1;
				else
					STATE <= S0;
				end if;
			when S1 =>
				if( DONE = '1') then
					CFG_ENB <= '0';
					STATE <= S2;
				else
					STATE <= S1;
				end if;
			when S2 =>
				if( CFG_SEL = '1') then
					CFG_ENB <= '1';
					STATE   <= S3;
				else
					STATE <= S2;
				end if;
			when S3 =>
				if( DONE = '0') then
					STATE   <= S0;
					CFG_ENB <= '0';
				else
					STATE <= S3;
				end if;				
			when others => STATE <= S0;
		end case;
	end if;
end process;		

end RTL;
