library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity EDX_TOP is
	Port ( CLK     : in  std_logic;
			 CLK72K  : in  std_logic;
			 SW_INIT : in  std_logic;

			 RXF_N    : in  std_logic;
			 RD_N     : out std_logic;
			 USB_DATA : in std_logic_vector( 7 downto 0 );

			 LED_DONE : out std_logic;

			 CLK1K1 : out std_logic;
			 CLK1K2 : out std_logic;

			 DONE : in  std_logic;
			 PROG : out std_logic;
			 CCLK : out std_logic;
			 DIN  : out std_logic;

			 DISP_RD      : out std_logic;
			 DISP_CLKSEl  : out std_logic;
			 DISP_INV_RST : out std_logic;
			 DISP_CE1     : out std_logic;
			 DISP_RST     : in  std_logic );

end EDX_TOP;

architecture RTL of EDX_TOP is

component USB_READ is
	Port ( CLK      : in  std_logic;
			 RXF_N    : in  std_logic;
			 RD_N     : out std_logic;
			 USB_DATA : in  std_logic_vector( 7 downto 0 );
			 USB_BSY  : out std_logic;
			 TGT_RDY  : in  std_logic;
			 TGT_DO   : out std_logic_vector( 7 downto 0 );
			 TGT_RD   : out std_logic );
end component;

component PLSGEN is
	Port( CLK   : in  std_logic;
         STB   : out std_logic );
end component;

component CLKDIV is
	Port ( CLK : in  std_logic;
			 DIV : out std_logic  );
end component;

component CONFIG is
	Port ( CLK      : in  std_logic; 
			 CE       : in  std_logic; 
 			 RST      : in  std_logic; 
			 CFG_DATA : in  std_logic_vector( 7 downto 0 );
			 CFG_RD   : in  std_logic;
			 READY    : in  std_logic;
			 DONE     : in  std_logic;
			 BUSY     : out std_logic;
			 CCLK     : out std_logic;
			 DIN      : out std_logic;
			 PROG     : out std_logic );
end component;

	signal CFG_DATA  : std_logic_vector( 7 downto 0 );
	signal CFG_RD    : std_logic;
	signal USB_READY : std_logic;
	signal USB_BUSY  : std_logic;
	signal TG_READY  : std_logic;
	signal TG_BUSY   : std_logic;
	signal RD_N_IN   : std_logic;
	signal CE        : std_logic;
	signal RST       : std_logic;
	signal CLK1K     : std_logic;

begin

process( CLK ) begin
	if( CLK'event and CLK='1') then
		if( CE = '1') then
			RST <= not SW_INIT;
		end if;
	end if;
end process;

	LED_DONE <= '0' when( DONE = '1') else 'Z';

	DISP_RD      <= '1';
	DISP_CLKSEL  <= '1';
	DISP_CE1     <= '1';
	DISP_INV_RST <= not DISP_RST;

	TG_READY  <= not TG_BUSY;
	USB_READY <= not USB_BUSY;

	RD_N <= RD_N_IN when( DONE = '0' ) else 'Z';

	U0 : USB_READ port map 
			 ( CLK      => CLK,
				RXF_N    => RXF_N,
				RD_N     => RD_N_IN,
				USB_DATA => USB_DATA,
				USB_BSY  => USB_BUSY,
				TGT_RDY  => TG_READY,
				TGT_DO   => CFG_DATA,
				TGT_RD   => CFG_RD );

	U1 : CONFIG port map
			 ( CLK      => CLK,
				CE       => CE,
				RST      => RST,
				CFG_DATA => CFG_DATA,
				CFG_RD   => CFG_RD,
				READY    => USB_READY,
				DONE     => DONE,
				BUSY     => TG_BUSY,
				CCLK     => CCLK,
				DIN      => DIN,
				PROG     => PROG );

	U2 : PLSGEN port map( CLK => CLK,    STB=>CE );
	U3 : CLKDIV port map( CLK => CLK72K, DIV=>CLK1K );

	CLK1K1 <= CLK1K;
	CLK1K2 <= CLK1K;

end RTL;


